package com.example.collectionofshortstories.view.authorization

import android.util.Log
import android.widget.Button
import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.layout.wrapContentSize
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonColors
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Divider
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import androidx.compose.material3.TextField
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.hilt.navigation.compose.hiltViewModel
import com.example.collectionofshortstories.domain.untils.Constants
import com.example.collectionofshortstories.navigation.Routes
import io.github.jan.supabase.gotrue.auth

@Composable
fun AuthorizationAndLogin(navHostController: NavHostController, viewModel: AuthorizationViewModel = hiltViewModel()) {
    val email = remember { mutableStateOf("") }
    val password = remember { mutableStateOf("") }

    LaunchedEffect(key1 = viewModel.navigationTo) {
        viewModel.navigationTo.collect { destination ->
            destination?.let {
                navHostController.navigate(destination)
            }
        }
    }

    Column(
        horizontalAlignment = Alignment.CenterHorizontally,
        modifier = Modifier
            .fillMaxSize()
            .background(Color(0xFFFCE0C6))
    ) {
        Column(
            horizontalAlignment = Alignment.CenterHorizontally,
            modifier = Modifier
                .padding(0.dp, 0.dp, 0.dp, 80.dp)
        ) {
            Text(
                text = "СБОРНИК РАССКАЗОВ",
                color = Color.Black,
                fontSize = 30.sp,
                fontWeight = FontWeight.Bold,
                modifier = Modifier
                    .padding(0.dp, 50.dp, 0.dp, 30.dp)
            )
            Divider(
                modifier = Modifier.fillMaxWidth(),
                thickness = 5.dp,
                color = Color.Black
            )
        }
        Column(
            horizontalAlignment = Alignment.CenterHorizontally,
        ) {
            Text(
                text = "Авторизация",
                color = Color.Black,
                fontSize = 30.sp
            )
            CreateTextFolder(email, password)

            Button(
                onClick = {
                    viewModel.onSignInEmailPassword(email.value, password.value)
                },
                colors = ButtonDefaults.buttonColors(
                    containerColor = Color(0xFFFCE0C6)
                ),
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(40.dp, 20.dp)
                    .border(BorderStroke(2.dp, Color.Black), shape = RoundedCornerShape(25.dp))

            ) {
                Text(
                    text = "Войти",
                    color = Color.Black
                )
            }
            if (viewModel.wrongSignIn.value) {
                Box(
                    modifier = Modifier
                        .border(BorderStroke(2.dp, Color.Black))
                ) {
                    Box(
                        modifier = Modifier
                            .background(Color.White)
                            .padding(6.dp)
                    ) {
                        Text(
                            text = "Неверный логин или пароль",
                            color = Color.Black,
                            modifier = Modifier
                                .padding(8.dp)
                        )
                    }
                }
            }
        }
    }
}

@Composable
fun CreateTextFolder(
    emailState: MutableState<String>,
    passwordState: MutableState<String>
) {
    TextField(
        value = emailState.value,
        onValueChange = { newEmail -> emailState.value = newEmail },
        maxLines = 1,
        placeholder = { Text("example@mail") },
        modifier = Modifier
            .padding(0.dp, 30.dp, 0.dp, 0.dp)

    )
    TextField(
        value = passwordState.value,
        onValueChange = { newPass -> passwordState.value = newPass },
        maxLines = 1,
        placeholder = { Text("password") },
        modifier = Modifier
            .padding(0.dp, 30.dp, 0.dp, 0.dp)
    )
}