package com.example.collectionofshortstories.view.catalog

import android.util.Log
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.State
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.collectionofshortstories.domain.untils.Constants
import com.example.collectionofshortstories.model.Article
import com.example.collectionofshortstories.model.Role
import com.example.collectionofshortstories.model.User
import dagger.hilt.android.lifecycle.HiltViewModel
import io.github.jan.supabase.gotrue.auth
import io.github.jan.supabase.postgrest.from
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext
import javax.inject.Inject

@HiltViewModel
class CatalogViewModel @Inject constructor(): ViewModel() {
    private val _articles: MutableStateFlow<List<Article>> = MutableStateFlow( listOf() )
    val articles: StateFlow<List<Article>> = _articles.asStateFlow()

    val showButton = mutableStateOf(false)

    fun GetArticles() {
        viewModelScope.launch {
            withContext(Dispatchers.IO) {

                val updatedArticles = Constants.supabase.from("articles")
                    .select()
                _articles.value = updatedArticles.decodeList<Article>()
            }
        }
    }

    fun GetUserRole() {
        viewModelScope.launch {
            val userDate = Constants.supabase.from("users").select {
                filter {
                    eq("id", Constants.supabase.auth.currentUserOrNull()!!.id)
                }
            }.decodeSingleOrNull<User>()
            val roleDate = Constants.supabase.from("roles")
                .select {
                    filter {
                        eq("id", userDate!!.id_role)
                    }
                }.decodeSingleOrNull<Role>()
            if (roleDate!!.title == "Писатель") {
                showButton.value = true
            }
        }
    }


}