package com.example.collectionofshortstories.view.createArticle

import android.app.Activity
import android.content.Intent
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.provider.MediaStore
import androidx.activity.compose.rememberLauncherForActivityResult
import androidx.activity.result.ActivityResult
import androidx.activity.result.contract.ActivityResultContracts
import androidx.compose.animation.expandIn
import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Divider
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.asImageBitmap
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.example.collectionofshortstories.R
import com.example.collectionofshortstories.view.authorization.AuthorizationViewModel
import com.example.collectionofshortstories.view.authorization.CreateTextFolder

@Composable
fun СreateArticle(
    navHostController: NavHostController,
    viewModel: СreateArticleViewModel = hiltViewModel()
) {
    var expanded by remember { mutableStateOf(false) }
    var selectedCategory by remember { mutableStateOf("Выберите категорию") }
    var textArticle = remember { mutableStateOf("") }
    var title = remember { mutableStateOf("") }

    val listCategories by viewModel.categories.collectAsState(initial = emptyList())
//    var selectedImage by remember { mutableStateOf<Bitmap>(BitmapFactory.decodeResource(context, R.drawable.load_program_icon)) }

//    val context = LocalContext.current
//    val launcher = rememberLauncherForActivityResult(
//        contract = ActivityResultContracts.StartActivityForResult()
//    ) { result: ActivityResult ->
//        if (result.resultCode == Activity.RESULT_OK) {
//            val uri = result.data?.data
//            if (uri != null) {
//                selectedImage = MediaStore.Images.Media.getBitmap(context.contentResolver, uri)
//            }
//        }
//    }
    LaunchedEffect(key1 = viewModel.navigationTo) {
        viewModel.navigationTo.collect { destination ->
            destination?.let {
                navHostController.navigate(destination)
            }
        }
    }

    viewModel.GetCategories()

    Column(
        horizontalAlignment = Alignment.CenterHorizontally,
        modifier = Modifier
            .fillMaxSize()
            .background(Color(0xFFFCE0C6))
    ) {
        Column(
            horizontalAlignment = Alignment.CenterHorizontally,
            modifier = Modifier
                .padding(0.dp, 0.dp, 0.dp, 80.dp)
        ) {
            Text(
                text = "СБОРНИК РАССКАЗОВ",
                color = Color.Black,
                fontSize = 30.sp,
                fontWeight = FontWeight.Bold,
                modifier = Modifier
                    .padding(0.dp, 30.dp, 0.dp, 30.dp)
            )
            Divider(
                modifier = Modifier.fillMaxWidth(),
                thickness = 5.dp,
                color = Color.Black
            )
        }
        Column(
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.SpaceEvenly
        ) {
            Text(
                text = "Создание рассказа",
                color = Color.Black,
                fontSize = 30.sp
            )

            TextField(
                value = title.value,
                onValueChange = { titleNew -> title.value = titleNew },
                maxLines = 1,
                placeholder = { Text("Название") },
                modifier = Modifier
                    .padding(0.dp, 30.dp, 0.dp, 0.dp)
            )
            TextField(
                value = textArticle.value,
                onValueChange = { textArticleNew -> textArticle.value = textArticleNew },
                maxLines = 1,
                placeholder = { Text("Текст рассказа") },
                modifier = Modifier
                    .padding(0.dp, 30.dp, 0.dp, 0.dp)
                    .weight(3f)
            )

            Button(
                modifier = Modifier
                    .padding(0.dp, 10.dp),
                onClick = { expanded = !expanded }
            ) {
                Text(text = selectedCategory)
            }
            DropdownMenu(
                expanded = expanded,
                onDismissRequest = { expanded = false },

                ) {
                for (categories in listCategories) {
                    DropdownMenuItem(onClick = {
                        selectedCategory = categories.title
                        expanded = false
                    },
                        text = { Text(categories.title) }
                    )
                }


            }
//            Button(onClick = {
//                launcher.launch(Intent(Intent.ACTION_PICK).apply {
//                    type = "image/*"
//                })
//            }) {
//                Text("Выбрать картинку")
//            }
//
//            if (selectedImage != null) {
//                val imageBitmap = selectedImage.asImageBitmap()
//
//                Image(bitmap = imageBitmap, contentDescription = "Selected image")
//            }
            Button(
                onClick = {
                    viewModel.InsertNewArticle(title.value, textArticle.value, selectedCategory)
                },
                colors = ButtonDefaults.buttonColors(
                    containerColor = Color(0xFFFCE0C6)
                ),
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(40.dp, 20.dp)
                    .border(BorderStroke(2.dp, Color.Black), shape = RoundedCornerShape(25.dp))

            ) {
                    Text(
                        text = "Сохранить рассказ",
                        color = Color.Black
                    )
                }

        }
    }
}

