package com.example.collectionofshortstories.view.createArticle

import android.util.Log
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.ui.tooling.preview.Preview
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import androidx.lifecycle.viewmodel.compose.viewModel
import com.example.collectionofshortstories.domain.untils.Constants
import com.example.collectionofshortstories.model.Article
import com.example.collectionofshortstories.model.Categories
import com.example.collectionofshortstories.navigation.Routes
import dagger.hilt.android.lifecycle.HiltViewModel
import io.github.jan.supabase.gotrue.auth
import io.github.jan.supabase.postgrest.from
import io.github.jan.supabase.postgrest.query.Count
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext
import java.util.UUID
import javax.inject.Inject

@HiltViewModel
class СreateArticleViewModel @Inject constructor() : ViewModel() {
    private val _categories: MutableStateFlow<List<Categories>> = MutableStateFlow( listOf() )
    val categories: StateFlow<List<Categories>> = _categories.asStateFlow()

    private var _navigationTo = MutableStateFlow<String?>(null)
    val navigationTo = _navigationTo.asStateFlow()

    fun GetCategories() {
        viewModelScope.launch {
            withContext(Dispatchers.IO) {
                val updatedCategories = Constants.supabase.from("categories")
                    .select()
                _categories.value = updatedCategories.decodeList<Categories>()
            }
        }
    }

    fun InsertNewArticle(titleArticleNew: String, textArticleNew: String, categoryArticle: String) {
        try {
            viewModelScope.launch {
                withContext(Dispatchers.IO) {
                    val maxId = Constants.supabase.from("articles")
                        .select {
                            count(
                                Count.EXACT
                            )
                        }.countOrNull()!!.toInt()

                    val NewArticle = Article(
                        id = maxId + 1,
                        id_author = Constants.supabase.auth.currentUserOrNull()!!.id,
                        title = titleArticleNew,
                        id_categories = Constants.supabase.from("categories")
                            .select {
                                filter {
                                    eq("title", categoryArticle)
                                }
                            }.decodeSingleOrNull<Categories>()!!.id,
                        text_articles = textArticleNew,
                        icon_article = ""
                    )

                    Constants.supabase.from("articles").insert(NewArticle)
                    _navigationTo.value = Routes.CATALOG
                }
            }
        }
        catch (e: Exception) {
            Log.d("Insert", e.toString())
            Log.d("Insert", e.message.toString())

        }
    }


}